## 沪深股通十大成交股

接口：hsgt_top10

描述：获取沪股通、深股通每日前十大成交详细数据，每天18~20点之间完成当日更新

输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | N | 股票代码（二选一） |
| trade_date | str | N | 交易日期（二选一） |
| start_date | str | N | 开始日期 |
| end_date | str | N | 结束日期 |
| market_type | str | N | 市场类型（1：沪市 3：深市） |

输出参数

| 名称 | 类型 | 描述 |
| --- | --- | --- |
| trade_date | str | 交易日期 |
| ts_code | str | 股票代码 |
| name | str | 股票名称 |
| close | float | 收盘价 |
| change | float | 涨跌额 |
| rank | int | 资金排名 |
| market_type | str | 市场类型（1：沪市 3：深市） |
| amount | float | 成交金额（元） |
| net_amount | float | 净成交金额（元） |
| buy | float | 买入金额（元） |
| sell | float | 卖出金额（元） |

接口用法

```python
pro = ts.pro_api()

pro.hsgt_top10(trade_date='20180725', market_type='1')
```

或者

```python
pro.query('hsgt_top10', ts_code='600519.SH', start_date='20180701', end_date='20180725')
```

数据样例

```python
trade_date    ts_code  name       close  change  rank  market_type  \
0   20180725  600009.SH  上海机场   62.69    2.0677     9            1   
```